givaro: C++ library for arithmetic and algebraic computations
=============================================================

Description
-----------

Givaro is a C++ library for arithmetic and algebraic computations. Its
main features are implementations of the basic arithmetic of many
mathematical entities: Primes fields, Extensions Fields, Finite Fields,
Finite Rings, Polynomials, Algebraic numbers, Arbitrary precision
integers and rationals (C++ wrappers over gmp) It also provides
data-structures and templated classes for the manipulation of basic
algebraic objects, such as vectors, matrices (dense, sparse,
structured), univariate polynomials (and therefore recursive
multivariate).

Website: https://casys.gricad-pages.univ-grenoble-alpes.fr/givaro/

SPKG Repository: https://bitbucket.org/malb/givaro-spkg

License
-------

-  GNU GPL


Upstream Contact
----------------

-  Clement Pernet
